@@ -120,10 +120,12 @@ pub struct Config {
 
 /// Creates the server config, reads .env values and sets defaults
 pub fn init() -> BetterResult<Config> {
+    // Parse .env file (do this before parsing the CLI opts)
+    dotenv().ok();
+
     // Parse CLI options, .env values, set defaults
     let opts: Opts = Opts::parse();
 
-    dotenv().ok();
     let config_dir = if let Some(dir) = &opts.config_dir {
         dir.clone()
     } else {
@@ -142,10 +144,10 @@ pub fn init() -> BetterResult<Config> {
     // Make sure to also edit the `default.env` if you introduce / change environment variables here.
     for (key, value) in env::vars() {
         match &*key {
-            "ATOMIC_CONFIG_PATH" => {
+            "ATOMIC_CONFIG_DIR" => {
                 config_file_path = value.parse().map_err(|e| {
                     format!(
-                        "Could not parse ATOMIC_CONFIG_PATH. Is {} a valid path? {}",
+                        "Could not parse ATOMIC_CONFIG_DIR. Is {} a valid path? {}",
                         value, e
                     )
                 })?;
